#!/usr/bin/perl

# This is used as a diagnostic to send to the module author

use strict;

use Data::Dumper;
use Graphics::Framebuffer;
$Data::Dumper::Sortkeys = 1;

my $fb = Graphics::Framebuffer->new('SHOW_ERRORS' => 1);
$fb->cls();

my $copy = $fb;

delete($copy->{'SCREEN'});

print STDERR Dumper($copy);

=head1 NAME

Framebuffer Information Dump

=head1 DESCRIPTION

This script is used to help the author diagnose (and fix) any problems you may be having with the Graphics::Framebuffer module

=head1 SYNOPSIS

 perl dump.pl 2> gfb_dump.txt

=cut
