#!perl -T

use strict;
use Test::More tests => 1;

use Graphics::Framebuffer;

$ENV{'PATH'} .= ':/usr/share/fonts';
my $F = Graphics::Framebuffer->new();

isa_ok($F,'Graphics::Framebuffer');
$F->cls();
